@@ -21,7 +21,9 @@
 
 #include "alkdateformat.h"
 #include "alkexception.h"
+#ifdef ENABLE_FINANCEQUOTE
 #include "alkfinancequoteprocess.h"
+#endif
 #include "alkonlinequoteprocess.h"
 #include "alkonlinequotesprofile.h"
 #include "alkonlinequotesprofilemanager.h"
@@ -123,6 +125,8 @@ public:
     void enter_loop();
     bool parsePrice(const QString &pricestr);
     bool parseDate(const QString &datestr);
+    bool downloadUrl(const KUrl& url);
+    bool processDownloadedFile(const KUrl& url, const QString& tmpFile);
 
 public slots:
     void slotLoadStarted();
@@ -301,42 +305,58 @@ bool AlkOnlineQuote::Private::launchNative(const QString &_symbol, const QString
         }
     } else {
         slotLoadStarted();
-
-        QString tmpFile;
-        if (KIO::NetAccess::download(url, tmpFile, 0)) {
-            // kDebug(Private::dbgArea()) << "Downloaded " << tmpFile;
-            kDebug(Private::dbgArea()) << "Downloaded" << tmpFile << "from" << url;
-            QFile f(tmpFile);
-            if (f.open(QIODevice::ReadOnly)) {
-                // Find out the page encoding and convert it to unicode
-                QByteArray page = f.readAll();
-                KEncodingProber prober(KEncodingProber::Universal);
-                prober.feed(page);
-                QTextCodec *codec = QTextCodec::codecForName(prober.encoding());
-                if (!codec) {
-                    codec = QTextCodec::codecForLocale();
-                }
-                QString quote = codec->toUnicode(page);
-                f.close();
-                emit m_p->status(i18n("URL found: %1...", url.prettyUrl()));
-                if (AlkOnlineQuotesProfileManager::instance().webPageEnabled())
-                    AlkOnlineQuotesProfileManager::instance().webPage()->setContent(quote.toLocal8Bit());
-                result = slotParseQuote(quote);
-            } else {
-                emit m_p->error(i18n("Failed to open downloaded file"));
-                m_errors |= Errors::URL;
-                result = slotParseQuote(QString());
-            }
-            KIO::NetAccess::removeTempFile(tmpFile);
-        } else {
-            emit m_p->error(KIO::NetAccess::lastErrorString());
-            m_errors |= Errors::URL;
-            result = slotParseQuote(QString());
-        }
+        result = downloadUrl(url);
     }
     return result;
 }
 
+bool AlkOnlineQuote::Private::processDownloadedFile(const KUrl& url, const QString& tmpFile)
+{
+    bool result = false;
+
+    QFile f(tmpFile);
+    if (f.open(QIODevice::ReadOnly)) {
+        // Find out the page encoding and convert it to unicode
+        QByteArray page = f.readAll();
+        KEncodingProber prober(KEncodingProber::Universal);
+        prober.feed(page);
+        QTextCodec *codec = QTextCodec::codecForName(prober.encoding());
+        if (!codec) {
+          codec = QTextCodec::codecForLocale();
+        }
+        QString quote = codec->toUnicode(page);
+        f.close();
+        emit m_p->status(i18n("URL found: %1...", url.prettyUrl()));
+        if (AlkOnlineQuotesProfileManager::instance().webPageEnabled())
+            AlkOnlineQuotesProfileManager::instance().webPage()->setContent(quote.toLocal8Bit());
+        result = slotParseQuote(quote);
+    } else {
+        emit m_p->error(i18n("Failed to open downloaded file"));
+        m_errors |= Errors::URL;
+        result = slotParseQuote(QString());
+    }
+    return result;
+}
+
+bool AlkOnlineQuote::Private::downloadUrl(const KUrl& url)
+{
+    bool result = false;
+
+    QString tmpFile;
+    if (KIO::NetAccess::download(url, tmpFile, nullptr)) {
+        // kDebug(Private::dbgArea()) << "Downloaded " << tmpFile;
+        kDebug(Private::dbgArea()) << "Downloaded" << tmpFile << "from" << url;
+        result = processDownloadedFile(url, tmpFile);
+        KIO::NetAccess::removeTempFile(tmpFile);
+    } else {
+        emit m_p->error(KIO::NetAccess::lastErrorString());
+        m_errors |= Errors::URL;
+        result = slotParseQuote(QString());
+    }
+    return result;
+}
+
+#ifdef ENABLE_FINANCEQUOTE
 bool AlkOnlineQuote::Private::launchFinanceQuote(const QString &_symbol, const QString &_id,
                                         const QString &_sourcename)
 {
@@ -374,6 +394,7 @@ bool AlkOnlineQuote::Private::launchFinanceQuote(const QString &_symbol, const Q
     }
     return result;
 }
+#endif
 
 bool AlkOnlineQuote::Private::parsePrice(const QString &_pricestr)
 {
@@ -560,10 +581,13 @@ void AlkOnlineQuote::setAcceptLanguage(const QString &language)
 
 bool AlkOnlineQuote::launch(const QString &_symbol, const QString &_id, const QString &_source)
 {
+#ifdef ENABLE_FINANCEQUOTE
     if (AlkOnlineQuoteSource::isFinanceQuote(_source) ||
             d->m_profile->type() == AlkOnlineQuotesProfile::Type::Script) {
         return d->launchFinanceQuote(_symbol, _id, _source);
-    } else if (_source.endsWith(".css")) {
+    } else
+#endif
+        if (_source.endsWith(".css")) {
         return d->launchWebKitCssSelector(_symbol, _id, _source);
     } else if (_source.endsWith(".webkit")) {
         return d->launchWebKitHtmlParser(_symbol, _id, _source);
