@@ -17,11 +17,13 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
  ***************************************************************************/
 
+#ifdef ENABLE_FINANCEQUOTE
+#include "alkfinancequoteprocess.h"
+#endif
 #include "alkonlinequotesprofile.h"
 #include "alkonlinequotesprofilemanager.h"
 
 #include "alkonlinequotesource.h"
-#include "alkfinancequoteprocess.h"
 
 #include <QApplication>
 #include <QDir>
@@ -59,11 +61,12 @@ public:
         , m_config(0)
         , m_type(Type::Undefined)
     {
-
+#ifdef ENABLE_FINANCEQUOTE
         if (m_financeQuoteScriptPath.isEmpty()) {
             m_financeQuoteScriptPath = KGlobal::dirs()->findResource("appdata",
                                                                      QString("misc/financequote.pl"));
         }
+#endif
     }
 
     ~Private()
@@ -89,14 +92,15 @@ public Q_SLOTS:
     void slotUpdatesFound(const KNS3::Entry::List &updates)
     {
         foreach (const KNS3::Entry &entry, updates) {
-            qDebug() << entry.name();
+            qDebug() << "update available in profile" << m_p->name() << "for" << entry.name() << entry.version() << entry.id() << entry.category() << entry.providerId();
+            emit m_p->updateAvailable(m_p->name(), entry.name());
         }
     }
 
     // to know about finished installations
     void entryStatusChanged(const KNS3::Entry &entry)
     {
-        qDebug() << entry.summary();
+        qDebug() << __FUNCTION__ << entry.name() << entry.status() << entry.summary();
     }
 
     const QStringList quoteSourcesNative()
@@ -135,6 +139,7 @@ public Q_SLOTS:
         return groups;
     }
 
+#ifdef ENABLE_FINANCEQUOTE
     const QStringList quoteSourcesFinanceQuote()
     {
         if (m_financeQuoteSources.empty()) { // run the process one time only
@@ -153,6 +158,7 @@ public Q_SLOTS:
         }
         return m_financeQuoteSources;
     }
+#endif
 
     const QStringList quoteSourcesSkrooge()
     {
@@ -196,14 +202,14 @@ public Q_SLOTS:
             AlkOnlineQuoteSource source("Alkimia Currency",
                                         "https://fx-rate.net/%1/%2",
                                         QString(), // symbolregexp
-                                        "1[ a-zA-Z]+=</span><br */?> *(\\d+\\.\\d+)",
+                                        "1[ a-zA-Z]+=</span><br */?> *(\\d+[\\.\\d]*)",
                                         "updated\\s\\d+:\\d+:\\d+\\(\\w+\\)\\s+(\\d{1,2}/\\d{2}/\\d{4})",
                                         "%d/%m/%y",
                                         true // skip HTML stripping
                                         );
             source.setProfile(m_p);
             result[source.name()] = source;
-#if defined(BUILD_WITH_WEBKIT)
+#if defined(BUILD_WITH_WEBKIT) || defined(BUILD_WITH_WEBENGINE)
             source.setName(source.name() + ".webkit");
             result[source.name()] = source;
 #endif
@@ -391,9 +397,11 @@ const QStringList AlkOnlineQuotesProfile::quoteSources()
     case AlkOnlineQuotesProfile::Type::KMyMoney5:
         result << d->quoteSourcesNative();
         break;
+#ifdef ENABLE_FINANCEQUOTE
     case AlkOnlineQuotesProfile::Type::Script:
         result << d->quoteSourcesFinanceQuote();
         break;
+#endif
     case AlkOnlineQuotesProfile::Type::None:
         result << d->defaultQuoteSources().keys();
         break;
