@@ -29,6 +29,7 @@
 #include <QCheckBox>
 #include <QDesktopServices>
 #include <QtDebug>
+#include <QTreeWidget>
 
 #include <KComponentData>
 #include <KIcon>
@@ -39,8 +40,9 @@
 #include <knewstuff3/uploaddialog.h>
 
 #if QT_VERSION < QT_VERSION_CHECK(5,0,0)
+static KComponentData alk(TRANSLATION_DOMAIN);
 #include <klocale.h>
-static KLocale _locale("alkimia");
+static KLocale _locale(TRANSLATION_DOMAIN);
 #define i18nc(context, text) ki18nc(context, text).toString(&_locale)
 #define i18n(text) ki18n(text).toString(&_locale)
 #define tr2i18n(text, context) ki18nc(context, text).toString(&_locale)
@@ -85,8 +87,8 @@ public slots:
     void slotLogError(const QString &s);
     void slotLogFailed(const QString &id, const QString &symbol);
     void slotLogQuote(const QString &id, const QString &symbol, const QDate &date, double price);
-    void slotEntryRenamed(QListWidgetItem *item);
-    void slotStartRename(QListWidgetItem *item);
+    void slotEntryRenamed(QTreeWidgetItem *item, int column);
+    void slotStartRename(QTreeWidgetItem *item, int column);
     void slotInstallEntries();
     void slotUploadEntry();
     void slotShowButton();
@@ -167,11 +169,19 @@ AlkOnlineQuotesWidget::Private::Private(bool showProfiles, bool showUpload, QWid
     connect(m_installButton, SIGNAL(clicked()), this, SLOT(slotInstallEntries()));
     connect(m_uploadButton, SIGNAL(clicked()), this, SLOT(slotUploadEntry()));
 
+    m_quoteSourceList->setColumnCount(2);
+    m_quoteSourceList->setHeaderLabels(QStringList() << i18n("Name") << i18n("Source"));
+    m_quoteSourceList->setRootIsDecorated(false);
+    m_quoteSourceList->header()->resizeSection(1, 5);
+    m_quoteSourceList->header()->setStretchLastSection(false);
+    m_quoteSourceList->header()->setResizeMode(0,QHeaderView::Stretch);
+    m_quoteSourceList->setSortingEnabled(true);
+
     connect(m_quoteSourceList, SIGNAL(itemSelectionChanged()), this, SLOT(slotLoadWidgets()));
-    connect(m_quoteSourceList, SIGNAL(itemChanged(QListWidgetItem *)), this,
-            SLOT(slotEntryRenamed(QListWidgetItem *)));
-    connect(m_quoteSourceList, SIGNAL(itemDoubleClicked(QListWidgetItem *)), this,
-            SLOT(slotStartRename(QListWidgetItem *)));
+    connect(m_quoteSourceList, SIGNAL(itemChanged(QTreeWidgetItem *, int)), this,
+            SLOT(slotEntryRenamed(QTreeWidgetItem *, int)));
+    connect(m_quoteSourceList, SIGNAL(itemDoubleClicked(QTreeWidgetItem *, int)), this,
+            SLOT(slotStartRename(QTreeWidgetItem *, int)));
 
     connect(m_editURL, SIGNAL(textChanged(QString)), this, SLOT(slotEntryChanged()));
     connect(m_editSymbol, SIGNAL(textChanged(QString)), this, SLOT(slotEntryChanged()));
@@ -208,6 +218,15 @@ void AlkOnlineQuotesWidget::Private::loadProfiles()
     loadQuotesList();
 }
 
+QString sourceTypeString(AlkOnlineQuoteSource &source)
+{
+    if (source.isGHNS())
+        return i18n("GHNS Source");
+    else if (source.isFinanceQuote())
+        return i18n("Finance::Quote");
+    return i18n("local");
+}
+
 void AlkOnlineQuotesWidget::Private::loadQuotesList(const bool updateResetList)
 {
     m_quoteInEditing = false;
@@ -225,25 +244,25 @@ void AlkOnlineQuotesWidget::Private::loadQuotesList(const bool updateResetList)
             continue;
         }
 
-        QListWidgetItem *item = new QListWidgetItem(*it);
+        QTreeWidgetItem *item = new QTreeWidgetItem(QStringList() << *it << sourceTypeString(source));
         item->setFlags(Qt::ItemIsEditable | Qt::ItemIsSelectable | Qt::ItemIsEnabled);
-        m_quoteSourceList->addItem(item);
+        m_quoteSourceList->addTopLevelItem(item);
         if (updateResetList) {
             m_resetList += source;
         }
     }
-    m_quoteSourceList->sortItems();
+    m_quoteSourceList->sortItems(0, Qt::AscendingOrder);
 
-    QListWidgetItem *item = nullptr;
+    QTreeWidgetItem *item = nullptr;
     if (!m_currentItem.name().isEmpty()) {
-        QList<QListWidgetItem*> items = m_quoteSourceList->findItems(m_currentItem.name(), Qt::MatchExactly);
+        QList<QTreeWidgetItem*> items = m_quoteSourceList->findItems(m_currentItem.name(), Qt::MatchExactly);
         if (items.size() > 0)
             item = items.at(0);
         if (item)
             m_quoteSourceList->setCurrentItem(item);
     }
     if (!item) {
-        item = m_quoteSourceList->item(0);
+        item = m_quoteSourceList->topLevelItem(0);
         if (item)
             m_quoteSourceList->setCurrentItem(item);
     }
@@ -254,8 +273,8 @@ void AlkOnlineQuotesWidget::Private::loadQuotesList(const bool updateResetList)
 
 void AlkOnlineQuotesWidget::Private::slotNewProfile()
 {
-    QListWidgetItem *item = new QListWidgetItem(dynamic_cast<QListWidget *>(m_profileList));
-    item->setText(QLatin1String("new profile"));
+    QTreeWidgetItem *item = new QTreeWidgetItem(dynamic_cast<QTreeWidget *>(m_profileList));
+    item->setText(0, QLatin1String("new profile"));
     item->setFlags(item->flags() | Qt::ItemIsEditable);
 }
 
@@ -283,7 +302,7 @@ void AlkOnlineQuotesWidget::Private::slotLoadProfile()
     }
 
     foreach (AlkOnlineQuotesProfile *profile, list) {
-        if (m_profileList->currentItem()->text() == profile->name()) {
+        if (m_profileList->currentItem() && m_profileList->currentItem()->text() == profile->name()) {
             m_profile = profile;
             loadQuotesList();
             m_installButton->setVisible(profile->hasGHNSSupport());
@@ -308,8 +327,8 @@ void AlkOnlineQuotesWidget::Private::slotLoadProfile()
 void AlkOnlineQuotesWidget::Private::slotLoadWidgets()
 {
     m_quoteInEditing = false;
-    QListWidgetItem *item = m_quoteSourceList->currentItem();
-    bool isFinanceQuoteSource = (item && AlkOnlineQuoteSource::isFinanceQuote(item->text())) ||
+    QTreeWidgetItem *item = m_quoteSourceList->currentItem();
+    bool isFinanceQuoteSource = (item && AlkOnlineQuoteSource::isFinanceQuote(item->text(0))) ||
             m_profile->type() == AlkOnlineQuotesProfile::Type::Script;
     bool enabled = item && !isFinanceQuoteSource;
 
@@ -328,7 +347,7 @@ void AlkOnlineQuotesWidget::Private::slotLoadWidgets()
     m_editDateFormat->clear();
 
     if (item) {
-        m_currentItem = AlkOnlineQuoteSource(item->text(), m_profile);
+        m_currentItem = AlkOnlineQuoteSource(item->text(0), m_profile);
         m_editURL->setText(m_currentItem.url());
         m_editSymbol->setText(m_currentItem.sym());
         m_editPrice->setText(m_currentItem.price());
@@ -367,12 +386,12 @@ void AlkOnlineQuotesWidget::Private::slotEntryChanged()
 
 void AlkOnlineQuotesWidget::Private::slotDeleteEntry()
 {
-    QList<QListWidgetItem *> items = m_quoteSourceList->findItems(
+    QList<QTreeWidgetItem *> items = m_quoteSourceList->findItems(
         m_currentItem.name(), Qt::MatchExactly);
     if (items.isEmpty()) {
         return;
     }
-    QListWidgetItem *item = items.at(0);
+    QTreeWidgetItem *item = items.at(0);
     if (!item) {
         return;
     }
@@ -395,12 +414,12 @@ void AlkOnlineQuotesWidget::Private::slotDeleteEntry()
 
 void AlkOnlineQuotesWidget::Private::slotDuplicateEntry()
 {
-    QList<QListWidgetItem *> items = m_quoteSourceList->findItems(
+    QList<QTreeWidgetItem *> items = m_quoteSourceList->findItems(
         m_currentItem.name(), Qt::MatchExactly);
     if (items.isEmpty()) {
         return;
     }
-    QListWidgetItem *item = items.at(0);
+    QTreeWidgetItem *item = items.at(0);
     if (!item) {
         return;
     }
@@ -517,14 +536,17 @@ void AlkOnlineQuotesWidget::Private::slotLogQuote(const QString &id, const QStri
                       price));
 }
 
-void AlkOnlineQuotesWidget::Private::slotStartRename(QListWidgetItem *item)
+void AlkOnlineQuotesWidget::Private::slotStartRename(QTreeWidgetItem *item, int column)
 {
+    Q_UNUSED(column);
+
     m_quoteInEditing = true;
     m_quoteSourceList->editItem(item);
 }
 
-void AlkOnlineQuotesWidget::Private::slotEntryRenamed(QListWidgetItem *item)
+void AlkOnlineQuotesWidget::Private::slotEntryRenamed(QTreeWidgetItem *item, int column)
 {
+    Q_UNUSED(column);
     //if there is no current item selected, exit
     if (m_quoteInEditing == false || !m_quoteSourceList->currentItem()
         || item != m_quoteSourceList->currentItem()) {
@@ -532,10 +554,10 @@ void AlkOnlineQuotesWidget::Private::slotEntryRenamed(QListWidgetItem *item)
     }
 
     m_quoteInEditing = false;
-    QString text = item->text();
+    QString text = item->text(0);
     int nameCount = 0;
-    for (int i = 0; i < m_quoteSourceList->count(); ++i) {
-        if (m_quoteSourceList->item(i)->text() == text) {
+    for (int i = 0; i < m_quoteSourceList->topLevelItemCount(); ++i) {
+        if (m_quoteSourceList->topLevelItem(i)->text(i) == text) {
             ++nameCount;
         }
     }
@@ -544,9 +566,9 @@ void AlkOnlineQuotesWidget::Private::slotEntryRenamed(QListWidgetItem *item)
     if (text.length() > 0 && nameCount == 1) {
         m_currentItem.rename(text);
     } else {
-        item->setText(m_currentItem.name());
+        item->setText(0, m_currentItem.name());
     }
-    m_quoteSourceList->sortItems();
+    m_quoteSourceList->sortItems(0, Qt::AscendingOrder);
     m_newButton->setEnabled(m_quoteSourceList->findItems(i18n(
                                                              "New Quote Source"),
                                                          Qt::MatchExactly).count() == 0);
