@@ -25,16 +25,16 @@
 #define KAboutData K4AboutData
 #else
 #include <KAboutData>
-#include <KHelpMenu>
-#include <QMenuBar>
 #endif
 
+#include <KHelpMenu>
+#include <QMenuBar>
 #include <KApplication>
 #include <KCmdLineArgs>
 
 int main(int argc, char **argv)
 {
-    KAboutData about("onlinequoteseditor",
+    KAboutData about("onlinequoteseditor" TARGET_SUFFIX,
                      "onlinequoteseditor",
                      ki18n("Online Quotes Editor"),
                      "1.0",
@@ -47,15 +47,17 @@ int main(int argc, char **argv)
 
     MainWindow w;
 
-#if QT_VERSION < QT_VERSION_CHECK(5,0,0)
+#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
+    KHelpMenu helpMenu(&w, about.shortDescription());
+#else
     KHelpMenu helpMenu(&w, &about, false);
+#endif
     helpMenu.menu();
     helpMenu.action(KHelpMenu::menuHelpContents)->setVisible(false);
-    helpMenu.action(KHelpMenu::menuSwitchLanguage)->setVisible(false);
     helpMenu.action(KHelpMenu::menuReportBug)->setVisible(false);
+    helpMenu.action(KHelpMenu::menuSwitchLanguage)->setVisible(true);
     helpMenu.action(KHelpMenu::menuAboutApp)->setText(i18n("&About %1", about.programName()));
     w.menuBar()->addMenu((QMenu*)helpMenu.menu());
-#endif
 
     w.show();
     return app.exec();
