@@ -82,7 +82,9 @@ MainWindow::MainWindow(QWidget *parent)
     manager.addProfile(new AlkOnlineQuotesProfile("skrooge5", AlkOnlineQuotesProfile::Type::Skrooge5, "skrooge-quotes.knsrc"));
     manager.addProfile(new AlkOnlineQuotesProfile("kmymoney5", AlkOnlineQuotesProfile::Type::KMyMoney5, "kmymoney-quotes.knsrc"));
 #endif
+#ifdef ENABLE_FINANCEQUOTE
     manager.addProfile(new AlkOnlineQuotesProfile("Finance::Quote", AlkOnlineQuotesProfile::Type::Script));
+#endif
     d->ui.setupUi(this);
 
     d->quotesWidget = new AlkOnlineQuotesWidget(true, true);
@@ -112,7 +114,10 @@ MainWindow::MainWindow(QWidget *parent)
     quoteDetailsWidget->setWidget(d->quotesWidget->quoteDetailsWidget());
     addDockWidget(Qt::RightDockWidgetArea, quoteDetailsWidget);
 
-#if defined(BUILD_WITH_WEBKIT)
+    connect(&AlkOnlineQuotesProfileManager::instance(), SIGNAL(updateAvailable(const QString &, const QString &)),
+            this, SLOT(slotUpdateAvailable(const QString &, const QString &)));
+
+#if defined(BUILD_WITH_WEBKIT) || defined(BUILD_WITH_WEBENGINE)
     manager.setWebPageEnabled(true);
     QDockWidget *browserWidget = new QDockWidget(i18n("Browser"), this);
     browserWidget->setObjectName("browserDockWidget");
@@ -163,6 +168,15 @@ MainWindow::~MainWindow()
     delete d;
 }
 
+void MainWindow::slotUpdateAvailable(const QString &profile, const QString &name)
+{
+    QString s = statusBar()->currentMessage();
+    if (!s.isEmpty())
+        s += " - ";
+    s += i18n("Update for '%1' available in profile '%2'", name, profile);
+    statusBar()->showMessage(s);
+}
+
 void MainWindow::closeEvent(QCloseEvent *event)
 {
     writePositionSettings();
